@@ -19,7 +19,7 @@ type bridgeVersionInfo struct {
 	SEPEpoch                  struct {
 		Major int `json:"Major,omitempty"`
 		Minor int `json:"Minor,omitempty"`
-	} `json:"SEPEpoch,omitempty"`
+	} `json:"SEPEpoch"`
 }
 
 type restoreVersionInfo struct {
@@ -44,7 +44,7 @@ type Asset struct {
 	ActualMinimumSystemPartition          int                `json:"ActualMinimumSystemPartition" plist:"ActualMinimumSystemPartition,omitempty"`
 	AutoUpdate                            bool               `json:"AutoUpdate" plist:"AutoUpdate,omitempty"`
 	AssetType                             string             `json:"AssetType" plist:"AssetType,omitempty"`
-	BridgeVersionInfo                     bridgeVersionInfo  `json:"BridgeVersionInfo,omitempty" plist:"BridgeVersionInfo,omitempty"`
+	BridgeVersionInfo                     bridgeVersionInfo  `json:"BridgeVersionInfo" plist:"BridgeVersionInfo,omitempty"`
 	Build                                 string             `json:"Build" plist:"Build,omitempty"`
 	DataTemplateSize                      int                `json:"DataTemplateSize" plist:"DataTemplateSize,omitempty"`
 	EAPFSEnabled                          bool               `json:"EAPFSEnabled,omitempty" plist:"EAPFSEnabled,omitempty"`
@@ -55,7 +55,7 @@ type Asset struct {
 	PreflightBuildManifest                []byte             `json:"PreflightBuildManifest" plist:"PreflightBuildManifest,omitempty"`
 	PreflightGlobalSignatures             []byte             `json:"PreflightGlobalSignatures" plist:"PreflightGlobalSignatures,omitempty"`
 	RestoreVersion                        string             `json:"RestoreVersion,omitempty" plist:"RestoreVersion,omitempty"`
-	RestoreVersionInfo                    restoreVersionInfo `json:"RestoreVersionInfo,omitempty" plist:"RestoreVersionInfo,omitempty"`
+	RestoreVersionInfo                    restoreVersionInfo `json:"RestoreVersionInfo" plist:"RestoreVersionInfo,omitempty"`
 	PrerequisiteBuild                     string             `json:"PrerequisiteBuild" plist:"PrerequisiteBuild,omitempty"`
 	PrerequisiteOSVersion                 string             `json:"PrerequisiteOSVersion" plist:"PrerequisiteOSVersion,omitempty"`
 	ProductVersionExtra                   string             `json:"ProductVersionExtra" plist:"ProductVersionExtra,omitempty"`
